.. Nbed documentation master file, created by
   sphinx-quickstart on Wed Feb 16 14:46:53 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. uncomment and add to toctree when ready
.. notebooks/A Scalable Approach to Quantum Simulation via Projection-based Embedding
Nbed
====



.. toctree::
   :maxdepth: 1
   :caption: Contents:

   embed
   driver
   config
   builder
   localizers
   scf
   utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
